@@ -286,12 +286,15 @@ static void
 populate_bar_for_selection (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv;
+  GtkSizeGroup *size;
 
   priv = self->priv;
 
   /* Hide close button */
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), FALSE);
 
+  size = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+
   /* Search button */
   add_search_button (self);
 
@@ -302,6 +305,11 @@ populate_bar_for_selection (BjbMainToolbar *self)
                                "text-button");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->select);
 
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->search);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->select);
+
+  g_object_unref (size);
+
   gtk_widget_set_tooltip_text (priv->select, _("Exit selection mode"));
   gtk_widget_reset_style (priv->select);
 
@@ -374,6 +382,7 @@ populate_bar_for_standard(BjbMainToolbar *self)
   BijiCollection *coll;
   GtkWidget *select_image;
   gboolean rtl;
+  GtkSizeGroup *size;
 
   rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
 
@@ -422,6 +431,12 @@ populate_bar_for_standard(BjbMainToolbar *self)
   g_signal_connect (priv->select,"clicked",
                     G_CALLBACK(on_selection_mode_clicked),self);
 
+  /* Align buttons */
+  size = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->select);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->new);
+  g_object_unref (size);
+
   /* Show close button */
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
 
@@ -585,28 +600,6 @@ delete_item_callback (GtkWidget *item, gpointer user_data)
           BIJI_ITEM (self->priv->note));
 }
 
-static void
-action_rename_note_callback (GtkWidget *w, gpointer user_data)
-{
-  BjbMainToolbar        *bar;
-  BjbMainToolbarPrivate *priv;
-  gchar                 *title;
-  BijiItem *item;
-
-  bar = BJB_MAIN_TOOLBAR (user_data);
-  priv = bar->priv;
-  item = BIJI_ITEM (priv->note);
-
-  title = note_title_dialog (priv->window,
-                             _("Rename Note"),
-                             biji_item_get_title (item));
-
-  if (!title)
-    return;
-
-  biji_note_obj_set_title (priv->note, title);
-  biji_note_obj_save_note (priv->note); //FIXME libbiji needs to to this auto
-}
 
 GtkWidget *
 bjb_note_menu_new (BjbMainToolbar *self)
@@ -660,12 +653,6 @@ bjb_note_menu_new (BjbMainToolbar *self)
 
   }
 
-  /* Rename, view tags, separtor */
-  item = gtk_menu_item_new_with_label(_("Rename"));
-  gtk_menu_shell_append(GTK_MENU_SHELL(result),item);
-  g_signal_connect(item,"activate",
-                   G_CALLBACK(action_rename_note_callback),self);
-
 
   if (biji_item_is_collectable (BIJI_ITEM (priv->note)))
   {
@@ -676,10 +663,6 @@ bjb_note_menu_new (BjbMainToolbar *self)
 
   }
 
-  item = gtk_separator_menu_item_new ();
-  gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
-
-
   /* Delete Note */
   item = gtk_menu_item_new_with_label(_("Delete this Note"));
   gtk_menu_shell_append(GTK_MENU_SHELL(result),item);
