@@ -93,7 +93,7 @@ action_color_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
       biji_note_obj_set_rgba (l->data, &color);
   }
 
-
+  bjb_main_view_set_selection_mode (self->priv->view, FALSE);
   g_list_free (selection);
 }
 
@@ -107,6 +107,7 @@ action_tag_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
   bjb_note_tag_dialog_new
     (GTK_WINDOW (bjb_main_view_get_window (self->priv->view)), selection);
 
+  bjb_main_view_set_selection_mode (self->priv->view, FALSE);
   g_list_free (selection);
 }
 
@@ -125,6 +126,7 @@ action_delete_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
     biji_note_book_remove_item (book, BIJI_ITEM (l->data));
   }
 
+  bjb_main_view_set_selection_mode (self->priv->view, FALSE);
   g_list_free (selection);
 }
 
@@ -240,6 +242,7 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
 
   /* Trash notes */
   priv->toolbar_trash = gtk_button_new_with_label (_("Delete"));
+  gtk_widget_set_valign (priv->toolbar_trash, GTK_ALIGN_CENTER);
   gtk_header_bar_pack_start (priv->bar, priv->toolbar_trash);
 
 
@@ -247,11 +250,13 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
   priv->toolbar_color = bjb_color_button_new ();
   gtk_widget_set_tooltip_text (GTK_WIDGET (priv->toolbar_color),
                                _("Note color"));
+  gtk_widget_set_valign (priv->toolbar_color, GTK_ALIGN_CENTER);
   gtk_header_bar_pack_end (priv->bar, priv->toolbar_color);
 
 
   /* Notes tags */
   priv->toolbar_tag = gtk_button_new_with_label (_("Add to Collection"));
+  gtk_widget_set_valign (priv->toolbar_tag, GTK_ALIGN_CENTER);
   gtk_header_bar_pack_end (priv->bar, priv->toolbar_tag);
 
 
